@@ -73,9 +73,10 @@ class DefaultProxyHandler(tornado.web.RequestHandler):
 
             proc = tornado.process.Subprocess(['streamlit', 'run', os.path.join(scan_folder_path, appname),
                                                '--server.port', str(port),
-                                               '--server.headless', 'True',
-                                               '--server.runOnSave', 'True',
-                                               '--server.enableCORS', 'False'],
+                                               '--server.headless', 'true',
+                                               '--server.runOnSave', 'true',
+                                               '--server.enableCORS', 'false',
+                                               '--server.enableXsrfProtection', 'false'],
                                               stdout=tornado.process.Subprocess.STREAM, stderr=tornado.process.Subprocess.STREAM,
                                               cwd=scan_folder_path)
 
